@@ -43,7 +43,8 @@
 
 
 ..geomedian_ndcor <- function(xy, w=NULL, threshold=100, maxiter=100) {
-	require(raster)
+	
+	requireNamespace('raster')
 	if (inherits(xy, 'SpatialPolygons') | inherits(xy, 'SpatialPoints')) {
 		stopifnot(raster::isLonLat(xy)) 
 		xy <- coordinates(xy)
